var __awaiter = this && this.__awaiter || function (thisArg, _arguments, P, generator) {
  return new (P || (P = Promise))(function (resolve, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    }

    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e) {
        reject(e);
      }
    }

    function step(result) {
      result.done ? resolve(result.value) : new P(function (resolve) {
        resolve(result.value);
      }).then(fulfilled, rejected);
    }

    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};

import * as React from "react";
import SFilter from "./comps/SFilter";
import STable from "./comps/STable";
import SModal from "./comps/SModal";
import { getList } from "./lib/api";
import { dealParams, dealRangePickerParams } from "./utils/params";
import { isObj } from "./utils/tool";
import verifyParams from "./lib/verifyParams";
import useColumns from "./hooks/useColumns";
import { compDidMount } from "./lifeCycleHooks/lifeCycle";
const {
  useState
} = React;
export default function SPage(props) {
  const {
    url,
    filters,
    tableColumns,
    searchHandler,
    isDealRangePicker = true,
    initialData,
    initialSearch = true,
    tableProps = {},
    rowKey
  } = props;
  tableProps["rowKey"] = rowKey;
  const [formData, setFormData] = useState(initialData);
  const [tableData, setTableData] = useState(props.tableData);
  const [pageSize, setPageSize] = useState(10);
  const [pageNum, setPageNum] = useState(1);
  const [totalNum, setTotalNum] = useState(0);
  const [modalChildren, setModalChildren] = useState(null);
  const [modalProps, setModalProps] = useState({});
  const [modalVisible, setModalVisible] = useState(false);
  const [searchLoading, setSearchLoading] = useState(false);
  const requiredParams = [];
  filters.forEach(({
    required,
    key
  }) => {
    if (required) requiredParams.push(key);
  });

  const getTableList = opt => __awaiter(this, void 0, void 0, function* () {
    if (isDealRangePicker) opt = dealRangePickerParams(opt);
    setSearchLoading(true);

    try {
      const {
        data: {
          list,
          total_num
        }
      } = yield getList(url, opt);
      setTotalNum(total_num);
      setTableData(list || []);
    } finally {
      setSearchLoading(false);
    }
  });

  const _searchHandler = () => {
    let opt = formData;
    const handlerRes = searchHandler && searchHandler(opt);
    isObj(handlerRes) && (opt = handlerRes);
    opt = dealParams(opt);
    if (!verifyParams(opt, requiredParams)) return;
    setPageNum(1);
    return getTableList(Object.assign({}, opt, {
      page_size: pageSize,
      page_num: 1
    }));
  };

  const openModal = (record, modalRender, modalProps = {}) => {
    setModalVisible(true);
    setModalChildren(modalRender && modalRender(record));
    setModalProps(modalProps);
  };

  const closeModal = () => {
    setModalVisible(false);
  };

  const pageChange = (pageNum, pageSize) => {
    setPageNum(pageNum);
    setPageSize(pageSize);
    getTableList(Object.assign({}, formData, {
      page_size: pageSize,
      page_num: pageNum
    }));
  };

  const columns = useColumns(filters, tableColumns, openModal);
  if (initialSearch) compDidMount(_searchHandler);
  return React.createElement("div", null, React.createElement(SFilter, Object.assign({
    updateFormData: setFormData,
    searchBtnHandler: _searchHandler,
    searchLoading: searchLoading
  }, props)), props.children, React.createElement(STable, {
    tableData: tableData,
    tableColumns: columns,
    tableProps: tableProps,
    pageChange: pageChange,
    pageSize: pageSize,
    pageNum: pageNum,
    totalNum: totalNum,
    loading: searchLoading
  }), React.createElement(SModal, {
    closeModal: closeModal,
    props: modalProps,
    visible: modalVisible
  }, modalChildren));
}
SPage.defaultProps = {
  filters: [],
  tableColumns: []
};